/* Copyright 2024 by COG9 Enterprises LLC
 * All rights reserved.
 * Title: date.c
 * Author: Jed Marti
 * Description: Date/time as a string.
 * Created: Sun Dec 15 13:58:30 2024
 * Revision History:
 *   Sun Dec 29 10:39:52 2024 - Code review.
 */

#include <stdlib.h>
#include <stdio.h>
#include <stdint.h>
#include <string.h>
#include <unistd.h>
#include <time.h>
#include <sys/time.h>

#include "mqtt.h"

// Sun Dec 29 10:42:23 2024 - This is what time(0) returned during the code review. If the value
// returned is less than this, then the system date isn't set or somebody discovered time travel.
#define OURTIME  1735494116

static char *bogusDate = "** Bad Date **";


  
char *date(void)
/*     Return the current date and time as a string. This comes from the Linux server which may
 *   or may not have the time set. If it's bogus (i.e. ct is < our current time) then flag
 *   the result.
 * Parameters: none
 * External References:
 *   bogusDate: String indicating time/date isn't set correctly.
 * Returned values: a string. Make sure you copy it if you're going to use in later.
 * Errors detected: If clock is in the past, the date isn't set - return the error string.
 */
{
  time_t ct;
  char   *ctc;
  ct = time(0);
  if (ct < OURTIME) return bogusDate;
  ctc = ctime(&ct);
  ctc[strlen(ctc) - 1] = 0;
  return ctc;
}


// EOF
