/* Copyright 2024 by COG9 Enterprises LLC
 * All rights reserved.
 * Title: disconnect.c
 * Author: Jed Marti
 * Description: Disconnect received from remote.
 * Created: Mon Dec  2 06:50:58 2024
 * Revision History:
 *   Tue Dec 24 11:34:34 2024 - Fix parameter list.
 *   Sun Dec 29 10:46:17 2024 - Code review.
 */

#include <stdlib.h>
#include <stdio.h>
#include <stdint.h>
#include <unistd.h>

#include "mqtt.h"
#include "protobuf.h"

// Network file handle.
extern int32_t FD;

// Noise level.
extern uint8_t Noise;

// Users - we lose these too.
extern Generic *Users;


void mqttDisconnect(uint8_t pt, uint8_t *pkt)
/*     The disconnect has no payload. Meshtastic does keep alive tests (pings) unless somebody
 *   figures out how to turn it off. 
 * Parameters:
 *   pt: Packet descriptor (ignored).
 *   rl: Number of bytes??? (ignored).
 * External References:
 *   Noise: How much output to generate.
 * Returned values: none
 * Errors detected: none
 */
{
  if (Noise > 0) printf("DISCONNECT\n");
  close(FD);
  FD = -1;

  // Remove users and topics. A new device must attach to restart.
  if (Noise > 5) printf("%s:%s:%d Clearing topics\n", __FILE__, __func__, __LINE__);
  clearTopics();
  if (Noise > 5) printf("%s:%s:%d Clearing Users\n", __FILE__, __func__, __LINE__);
  gc(Users);
  Users = NULL;
}


// EOF
